@@ -19,6 +19,8 @@
 
 #include "evolution-ews-config.h"
 
+#include <calendar/gui/calendar-config.h>
+
 #include "e-ews-message.h"
 
 #include "e-ews-calendar-utils.h"
@@ -218,6 +220,7 @@ e_ews_cal_utils_set_time (ESoapMessage *msg,
 			  icaltimetype *tt,
 			  gboolean with_timezone)
 {
+	struct icaltimetype local_tt;
 	gchar *str;
 	gchar *tz_ident = NULL;
 
@@ -245,6 +248,13 @@ e_ews_cal_utils_set_time (ESoapMessage *msg,
 		}
 	}
 
+	if (tt->is_date) {
+		local_tt = *tt;
+		local_tt.zone = calendar_config_get_icaltimezone ();
+		local_tt = icaltime_from_timet_with_zone (icaltime_as_timet_with_zone (local_tt, local_tt.zone), FALSE, icaltimezone_get_utc_timezone ());
+		tt = &local_tt;
+	}
+
 	str = g_strdup_printf (
 		"%04d-%02d-%02dT%02d:%02d:%02d%s",
 		tt->year, tt->month, tt->day,
