@@ -35,7 +35,8 @@ typedef enum {
 	E_EWS_FOLDER_TYPE_CALENDAR,
 	E_EWS_FOLDER_TYPE_CONTACTS,
 	E_EWS_FOLDER_TYPE_SEARCH,
-	E_EWS_FOLDER_TYPE_TASKS
+	E_EWS_FOLDER_TYPE_TASKS,
+	E_EWS_FOLDER_TYPE_MEMOS
 } EEwsFolderType;
 
 typedef enum {
